pub fn attr_signing_key(shared_secret: &SharedSecret) -> HS256Expand description
Computes the jwt::HS256 key used to sign Attr from the secret shared between the
authentication server and pubhubs central.
pub fn attr_signing_key(shared_secret: &SharedSecret) -> HS256Computes the jwt::HS256 key used to sign Attr from the secret shared between the
authentication server and pubhubs central.