master_enc_key_part_hash

Function master_enc_key_part_hash 

pub fn master_enc_key_part_hash(part: &PublicKey) -> Id
Hash of a master encryption key part (x_T B or x_PHC B), published in the constellation and discovery info in place of the part itself, so the part is not exposed in the clear.