pub fn phc_user_object_hmac(object_id: Id, secret: impl DigestibleSecret) -> IdExpand description
Derives an hmac for a user object stored at pubhubs central.
pub fn phc_user_object_hmac(object_id: Id, secret: impl DigestibleSecret) -> IdDerives an hmac for a user object stored at pubhubs central.